==> lightdash_client_python-0.1200.0-py3-none-any.whl: lightdash_client/api/integrations/update_custom_settings.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.api_slack_custom_settings_response import ApiSlackCustomSettingsResponse
from ...models.slack_app_custom_settings import SlackAppCustomSettings
from ...types import Response


def _get_kwargs(
    *,
    body: SlackAppCustomSettings,
) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}

    _kwargs: Dict[str, Any] = {
        "method": "put",
        "url": "/api/v1/slack/custom-settings",
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[ApiSlackCustomSettingsResponse]:
    if response.status_code == HTTPStatus.OK:
        response_200 = ApiSlackCustomSettingsResponse.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[ApiSlackCustomSettingsResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: SlackAppCustomSettings,
) -> Response[ApiSlackCustomSettingsResponse]:
    """Update slack notification channel to send notifications to scheduled jobs fail

    Args:
        body (SlackAppCustomSettings):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ApiSlackCustomSettingsResponse]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    body: SlackAppCustomSettings,
) -> Optional[ApiSlackCustomSettingsResponse]:
    """Update slack notification channel to send notifications to scheduled jobs fail

    Args:
        body (SlackAppCustomSettings):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ApiSlackCustomSettingsResponse
    """

    return sync_detailed(
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: SlackAppCustomSettings,
) -> Response[ApiSlackCustomSettingsResponse]:
    """Update slack notification channel to send notifications to scheduled jobs fail

    Args:
        body (SlackAppCustomSettings):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ApiSlackCustomSettingsResponse]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    body: SlackAppCustomSettings,
) -> Optional[ApiSlackCustomSettingsResponse]:
    """Update slack notification channel to send notifications to scheduled jobs fail

    Args:
        body (SlackAppCustomSettings):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ApiSlackCustomSettingsResponse
    """

    return (
        await asyncio_detailed(
            client=client,
            body=body,
        )
    ).parsed

==> lightdash_client_python-0.1403.1-py3-none-any.whl: lightdash_client/api/integrations/update_custom_settings.py <==
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.api_slack_custom_settings_response import ApiSlackCustomSettingsResponse
from ...models.slack_app_custom_settings import SlackAppCustomSettings
from ...types import UNSET, Response


def _get_kwargs(
    *,
    body: SlackAppCustomSettings,
) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}

    _kwargs: Dict[str, Any] = {
        "method": "put",
        "url": "/api/v1/slack/custom-settings",
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[ApiSlackCustomSettingsResponse]:
    if response.status_code == HTTPStatus.OK:
        response_200 = ApiSlackCustomSettingsResponse.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[ApiSlackCustomSettingsResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: SlackAppCustomSettings,
) -> Response[ApiSlackCustomSettingsResponse]:
    """Update slack notification channel to send notifications to scheduled jobs fail

    Args:
        body (SlackAppCustomSettings):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ApiSlackCustomSettingsResponse]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    body: SlackAppCustomSettings,
) -> Optional[ApiSlackCustomSettingsResponse]:
    """Update slack notification channel to send notifications to scheduled jobs fail

    Args:
        body (SlackAppCustomSettings):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ApiSlackCustomSettingsResponse
    """

    return sync_detailed(
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: SlackAppCustomSettings,
) -> Response[ApiSlackCustomSettingsResponse]:
    """Update slack notification channel to send notifications to scheduled jobs fail

    Args:
        body (SlackAppCustomSettings):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ApiSlackCustomSettingsResponse]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    body: SlackAppCustomSettings,
) -> Optional[ApiSlackCustomSettingsResponse]:
    """Update slack notification channel to send notifications to scheduled jobs fail

    Args:
        body (SlackAppCustomSettings):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ApiSlackCustomSettingsResponse
    """

    return (
        await asyncio_detailed(
            client=client,
            body=body,
        )
    ).parsed
